"""
Type annotations for license-manager service type definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_license_manager/type_defs/)

Usage::

    ```python
    from types_boto3_license_manager.type_defs import AcceptGrantRequestRequestTypeDef

    data: AcceptGrantRequestRequestTypeDef = ...
    ```

Copyright 2024 Vlad Emelianov
"""

from __future__ import annotations

import sys
from datetime import datetime
from typing import Sequence, Union

from .literals import (
    ActivationOverrideBehaviorType,
    AllowedOperationType,
    CheckoutTypeType,
    EntitlementDataUnitType,
    EntitlementUnitType,
    GrantStatusType,
    InventoryFilterConditionType,
    LicenseConfigurationStatusType,
    LicenseConversionTaskStatusType,
    LicenseCountingTypeType,
    LicenseDeletionStatusType,
    LicenseStatusType,
    ReceivedStatusType,
    RenewTypeType,
    ReportFrequencyTypeType,
    ReportTypeType,
    ResourceTypeType,
)

if sys.version_info >= (3, 12):
    from typing import Literal, NotRequired, TypedDict
else:
    from typing_extensions import Literal, NotRequired, TypedDict


__all__ = (
    "AcceptGrantRequestRequestTypeDef",
    "AcceptGrantResponseTypeDef",
    "AutomatedDiscoveryInformationTypeDef",
    "BorrowConfigurationTypeDef",
    "CheckInLicenseRequestRequestTypeDef",
    "CheckoutBorrowLicenseRequestRequestTypeDef",
    "CheckoutBorrowLicenseResponseTypeDef",
    "CheckoutLicenseRequestRequestTypeDef",
    "CheckoutLicenseResponseTypeDef",
    "ConsumedLicenseSummaryTypeDef",
    "ConsumptionConfigurationTypeDef",
    "CreateGrantRequestRequestTypeDef",
    "CreateGrantResponseTypeDef",
    "CreateGrantVersionRequestRequestTypeDef",
    "CreateGrantVersionResponseTypeDef",
    "CreateLicenseConfigurationRequestRequestTypeDef",
    "CreateLicenseConfigurationResponseTypeDef",
    "CreateLicenseConversionTaskForResourceRequestRequestTypeDef",
    "CreateLicenseConversionTaskForResourceResponseTypeDef",
    "CreateLicenseManagerReportGeneratorRequestRequestTypeDef",
    "CreateLicenseManagerReportGeneratorResponseTypeDef",
    "CreateLicenseRequestRequestTypeDef",
    "CreateLicenseResponseTypeDef",
    "CreateLicenseVersionRequestRequestTypeDef",
    "CreateLicenseVersionResponseTypeDef",
    "CreateTokenRequestRequestTypeDef",
    "CreateTokenResponseTypeDef",
    "DatetimeRangeTypeDef",
    "DeleteGrantRequestRequestTypeDef",
    "DeleteGrantResponseTypeDef",
    "DeleteLicenseConfigurationRequestRequestTypeDef",
    "DeleteLicenseManagerReportGeneratorRequestRequestTypeDef",
    "DeleteLicenseRequestRequestTypeDef",
    "DeleteLicenseResponseTypeDef",
    "DeleteTokenRequestRequestTypeDef",
    "EntitlementDataTypeDef",
    "EntitlementTypeDef",
    "EntitlementUsageTypeDef",
    "ExtendLicenseConsumptionRequestRequestTypeDef",
    "ExtendLicenseConsumptionResponseTypeDef",
    "FilterTypeDef",
    "GetAccessTokenRequestRequestTypeDef",
    "GetAccessTokenResponseTypeDef",
    "GetGrantRequestRequestTypeDef",
    "GetGrantResponseTypeDef",
    "GetLicenseConfigurationRequestRequestTypeDef",
    "GetLicenseConfigurationResponseTypeDef",
    "GetLicenseConversionTaskRequestRequestTypeDef",
    "GetLicenseConversionTaskResponseTypeDef",
    "GetLicenseManagerReportGeneratorRequestRequestTypeDef",
    "GetLicenseManagerReportGeneratorResponseTypeDef",
    "GetLicenseRequestRequestTypeDef",
    "GetLicenseResponseTypeDef",
    "GetLicenseUsageRequestRequestTypeDef",
    "GetLicenseUsageResponseTypeDef",
    "GetServiceSettingsResponseTypeDef",
    "GrantTypeDef",
    "GrantedLicenseTypeDef",
    "InventoryFilterTypeDef",
    "IssuerDetailsTypeDef",
    "IssuerTypeDef",
    "LicenseConfigurationAssociationTypeDef",
    "LicenseConfigurationTypeDef",
    "LicenseConfigurationUsageTypeDef",
    "LicenseConversionContextTypeDef",
    "LicenseConversionTaskTypeDef",
    "LicenseOperationFailureTypeDef",
    "LicenseSpecificationTypeDef",
    "LicenseTypeDef",
    "LicenseUsageTypeDef",
    "ListAssociationsForLicenseConfigurationRequestPaginateTypeDef",
    "ListAssociationsForLicenseConfigurationRequestRequestTypeDef",
    "ListAssociationsForLicenseConfigurationResponseTypeDef",
    "ListDistributedGrantsRequestRequestTypeDef",
    "ListDistributedGrantsResponseTypeDef",
    "ListFailuresForLicenseConfigurationOperationsRequestRequestTypeDef",
    "ListFailuresForLicenseConfigurationOperationsResponseTypeDef",
    "ListLicenseConfigurationsRequestPaginateTypeDef",
    "ListLicenseConfigurationsRequestRequestTypeDef",
    "ListLicenseConfigurationsResponseTypeDef",
    "ListLicenseConversionTasksRequestRequestTypeDef",
    "ListLicenseConversionTasksResponseTypeDef",
    "ListLicenseManagerReportGeneratorsRequestRequestTypeDef",
    "ListLicenseManagerReportGeneratorsResponseTypeDef",
    "ListLicenseSpecificationsForResourceRequestPaginateTypeDef",
    "ListLicenseSpecificationsForResourceRequestRequestTypeDef",
    "ListLicenseSpecificationsForResourceResponseTypeDef",
    "ListLicenseVersionsRequestRequestTypeDef",
    "ListLicenseVersionsResponseTypeDef",
    "ListLicensesRequestRequestTypeDef",
    "ListLicensesResponseTypeDef",
    "ListReceivedGrantsForOrganizationRequestRequestTypeDef",
    "ListReceivedGrantsForOrganizationResponseTypeDef",
    "ListReceivedGrantsRequestRequestTypeDef",
    "ListReceivedGrantsResponseTypeDef",
    "ListReceivedLicensesForOrganizationRequestRequestTypeDef",
    "ListReceivedLicensesForOrganizationResponseTypeDef",
    "ListReceivedLicensesRequestRequestTypeDef",
    "ListReceivedLicensesResponseTypeDef",
    "ListResourceInventoryRequestPaginateTypeDef",
    "ListResourceInventoryRequestRequestTypeDef",
    "ListResourceInventoryResponseTypeDef",
    "ListTagsForResourceRequestRequestTypeDef",
    "ListTagsForResourceResponseTypeDef",
    "ListTokensRequestRequestTypeDef",
    "ListTokensResponseTypeDef",
    "ListUsageForLicenseConfigurationRequestPaginateTypeDef",
    "ListUsageForLicenseConfigurationRequestRequestTypeDef",
    "ListUsageForLicenseConfigurationResponseTypeDef",
    "ManagedResourceSummaryTypeDef",
    "MetadataTypeDef",
    "OptionsTypeDef",
    "OrganizationConfigurationTypeDef",
    "PaginatorConfigTypeDef",
    "ProductInformationFilterOutputTypeDef",
    "ProductInformationFilterTypeDef",
    "ProductInformationFilterUnionTypeDef",
    "ProductInformationOutputTypeDef",
    "ProductInformationTypeDef",
    "ProductInformationUnionTypeDef",
    "ProvisionalConfigurationTypeDef",
    "ReceivedMetadataTypeDef",
    "RejectGrantRequestRequestTypeDef",
    "RejectGrantResponseTypeDef",
    "ReportContextOutputTypeDef",
    "ReportContextTypeDef",
    "ReportFrequencyTypeDef",
    "ReportGeneratorTypeDef",
    "ResourceInventoryTypeDef",
    "ResponseMetadataTypeDef",
    "S3LocationTypeDef",
    "TagResourceRequestRequestTypeDef",
    "TagTypeDef",
    "TokenDataTypeDef",
    "UntagResourceRequestRequestTypeDef",
    "UpdateLicenseConfigurationRequestRequestTypeDef",
    "UpdateLicenseManagerReportGeneratorRequestRequestTypeDef",
    "UpdateLicenseSpecificationsForResourceRequestRequestTypeDef",
    "UpdateServiceSettingsRequestRequestTypeDef",
)


class AcceptGrantRequestRequestTypeDef(TypedDict):
    GrantArn: str


class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]


class AutomatedDiscoveryInformationTypeDef(TypedDict):
    LastRunTime: NotRequired[datetime]


class BorrowConfigurationTypeDef(TypedDict):
    AllowEarlyCheckIn: bool
    MaxTimeToLiveInMinutes: int


class CheckInLicenseRequestRequestTypeDef(TypedDict):
    LicenseConsumptionToken: str
    Beneficiary: NotRequired[str]


class EntitlementDataTypeDef(TypedDict):
    Name: str
    Unit: EntitlementDataUnitType
    Value: NotRequired[str]


class MetadataTypeDef(TypedDict):
    Name: NotRequired[str]
    Value: NotRequired[str]


class ConsumedLicenseSummaryTypeDef(TypedDict):
    ResourceType: NotRequired[ResourceTypeType]
    ConsumedLicenses: NotRequired[int]


class ProvisionalConfigurationTypeDef(TypedDict):
    MaxTimeToLiveInMinutes: int


class CreateGrantRequestRequestTypeDef(TypedDict):
    ClientToken: str
    GrantName: str
    LicenseArn: str
    Principals: Sequence[str]
    HomeRegion: str
    AllowedOperations: Sequence[AllowedOperationType]


class OptionsTypeDef(TypedDict):
    ActivationOverrideBehavior: NotRequired[ActivationOverrideBehaviorType]


class TagTypeDef(TypedDict):
    Key: NotRequired[str]
    Value: NotRequired[str]


class LicenseConversionContextTypeDef(TypedDict):
    UsageOperation: NotRequired[str]


class ReportContextTypeDef(TypedDict):
    licenseConfigurationArns: Sequence[str]


class ReportFrequencyTypeDef(TypedDict):
    value: NotRequired[int]
    period: NotRequired[ReportFrequencyTypeType]


class DatetimeRangeTypeDef(TypedDict):
    Begin: str
    End: NotRequired[str]


class EntitlementTypeDef(TypedDict):
    Name: str
    Unit: EntitlementUnitType
    Value: NotRequired[str]
    MaxCount: NotRequired[int]
    Overage: NotRequired[bool]
    AllowCheckIn: NotRequired[bool]


class IssuerTypeDef(TypedDict):
    Name: str
    SignKey: NotRequired[str]


class CreateTokenRequestRequestTypeDef(TypedDict):
    LicenseArn: str
    ClientToken: str
    RoleArns: NotRequired[Sequence[str]]
    ExpirationInDays: NotRequired[int]
    TokenProperties: NotRequired[Sequence[str]]


class DeleteGrantRequestRequestTypeDef(TypedDict):
    GrantArn: str
    Version: str
    StatusReason: NotRequired[str]


class DeleteLicenseConfigurationRequestRequestTypeDef(TypedDict):
    LicenseConfigurationArn: str


class DeleteLicenseManagerReportGeneratorRequestRequestTypeDef(TypedDict):
    LicenseManagerReportGeneratorArn: str


class DeleteLicenseRequestRequestTypeDef(TypedDict):
    LicenseArn: str
    SourceVersion: str


class DeleteTokenRequestRequestTypeDef(TypedDict):
    TokenId: str


class EntitlementUsageTypeDef(TypedDict):
    Name: str
    ConsumedValue: str
    Unit: EntitlementDataUnitType
    MaxCount: NotRequired[str]


class ExtendLicenseConsumptionRequestRequestTypeDef(TypedDict):
    LicenseConsumptionToken: str
    DryRun: NotRequired[bool]


class FilterTypeDef(TypedDict):
    Name: NotRequired[str]
    Values: NotRequired[Sequence[str]]


class GetAccessTokenRequestRequestTypeDef(TypedDict):
    Token: str
    TokenProperties: NotRequired[Sequence[str]]


class GetGrantRequestRequestTypeDef(TypedDict):
    GrantArn: str
    Version: NotRequired[str]


class GetLicenseConfigurationRequestRequestTypeDef(TypedDict):
    LicenseConfigurationArn: str


class ManagedResourceSummaryTypeDef(TypedDict):
    ResourceType: NotRequired[ResourceTypeType]
    AssociationCount: NotRequired[int]


class GetLicenseConversionTaskRequestRequestTypeDef(TypedDict):
    LicenseConversionTaskId: str


class GetLicenseManagerReportGeneratorRequestRequestTypeDef(TypedDict):
    LicenseManagerReportGeneratorArn: str


class GetLicenseRequestRequestTypeDef(TypedDict):
    LicenseArn: str
    Version: NotRequired[str]


class GetLicenseUsageRequestRequestTypeDef(TypedDict):
    LicenseArn: str


class OrganizationConfigurationTypeDef(TypedDict):
    EnableIntegration: bool


class IssuerDetailsTypeDef(TypedDict):
    Name: NotRequired[str]
    SignKey: NotRequired[str]
    KeyFingerprint: NotRequired[str]


class ReceivedMetadataTypeDef(TypedDict):
    ReceivedStatus: NotRequired[ReceivedStatusType]
    ReceivedStatusReason: NotRequired[str]
    AllowedOperations: NotRequired[list[AllowedOperationType]]


class InventoryFilterTypeDef(TypedDict):
    Name: str
    Condition: InventoryFilterConditionType
    Value: NotRequired[str]


class LicenseConfigurationAssociationTypeDef(TypedDict):
    ResourceArn: NotRequired[str]
    ResourceType: NotRequired[ResourceTypeType]
    ResourceOwnerId: NotRequired[str]
    AssociationTime: NotRequired[datetime]
    AmiAssociationScope: NotRequired[str]


class LicenseConfigurationUsageTypeDef(TypedDict):
    ResourceArn: NotRequired[str]
    ResourceType: NotRequired[ResourceTypeType]
    ResourceStatus: NotRequired[str]
    ResourceOwnerId: NotRequired[str]
    AssociationTime: NotRequired[datetime]
    ConsumedLicenses: NotRequired[int]


class LicenseSpecificationTypeDef(TypedDict):
    LicenseConfigurationArn: str
    AmiAssociationScope: NotRequired[str]


class PaginatorConfigTypeDef(TypedDict):
    MaxItems: NotRequired[int]
    PageSize: NotRequired[int]
    StartingToken: NotRequired[str]


class ListAssociationsForLicenseConfigurationRequestRequestTypeDef(TypedDict):
    LicenseConfigurationArn: str
    MaxResults: NotRequired[int]
    NextToken: NotRequired[str]


class ListFailuresForLicenseConfigurationOperationsRequestRequestTypeDef(TypedDict):
    LicenseConfigurationArn: str
    MaxResults: NotRequired[int]
    NextToken: NotRequired[str]


class ListLicenseSpecificationsForResourceRequestRequestTypeDef(TypedDict):
    ResourceArn: str
    MaxResults: NotRequired[int]
    NextToken: NotRequired[str]


class ListLicenseVersionsRequestRequestTypeDef(TypedDict):
    LicenseArn: str
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class ResourceInventoryTypeDef(TypedDict):
    ResourceId: NotRequired[str]
    ResourceType: NotRequired[ResourceTypeType]
    ResourceArn: NotRequired[str]
    Platform: NotRequired[str]
    PlatformVersion: NotRequired[str]
    ResourceOwningAccountId: NotRequired[str]


class ListTagsForResourceRequestRequestTypeDef(TypedDict):
    ResourceArn: str


class TokenDataTypeDef(TypedDict):
    TokenId: NotRequired[str]
    TokenType: NotRequired[str]
    LicenseArn: NotRequired[str]
    ExpirationTime: NotRequired[str]
    TokenProperties: NotRequired[list[str]]
    RoleArns: NotRequired[list[str]]
    Status: NotRequired[str]


class ProductInformationFilterOutputTypeDef(TypedDict):
    ProductInformationFilterName: str
    ProductInformationFilterComparator: str
    ProductInformationFilterValue: NotRequired[list[str]]


class ProductInformationFilterTypeDef(TypedDict):
    ProductInformationFilterName: str
    ProductInformationFilterComparator: str
    ProductInformationFilterValue: NotRequired[Sequence[str]]


class RejectGrantRequestRequestTypeDef(TypedDict):
    GrantArn: str


class ReportContextOutputTypeDef(TypedDict):
    licenseConfigurationArns: list[str]


class S3LocationTypeDef(TypedDict):
    bucket: NotRequired[str]
    keyPrefix: NotRequired[str]


class UntagResourceRequestRequestTypeDef(TypedDict):
    ResourceArn: str
    TagKeys: Sequence[str]


class AcceptGrantResponseTypeDef(TypedDict):
    GrantArn: str
    Status: GrantStatusType
    Version: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateGrantResponseTypeDef(TypedDict):
    GrantArn: str
    Status: GrantStatusType
    Version: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateGrantVersionResponseTypeDef(TypedDict):
    GrantArn: str
    Status: GrantStatusType
    Version: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateLicenseConfigurationResponseTypeDef(TypedDict):
    LicenseConfigurationArn: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateLicenseConversionTaskForResourceResponseTypeDef(TypedDict):
    LicenseConversionTaskId: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateLicenseManagerReportGeneratorResponseTypeDef(TypedDict):
    LicenseManagerReportGeneratorArn: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateLicenseResponseTypeDef(TypedDict):
    LicenseArn: str
    Status: LicenseStatusType
    Version: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateLicenseVersionResponseTypeDef(TypedDict):
    LicenseArn: str
    Version: str
    Status: LicenseStatusType
    ResponseMetadata: ResponseMetadataTypeDef


class CreateTokenResponseTypeDef(TypedDict):
    TokenId: str
    TokenType: Literal["REFRESH_TOKEN"]
    Token: str
    ResponseMetadata: ResponseMetadataTypeDef


class DeleteGrantResponseTypeDef(TypedDict):
    GrantArn: str
    Status: GrantStatusType
    Version: str
    ResponseMetadata: ResponseMetadataTypeDef


class DeleteLicenseResponseTypeDef(TypedDict):
    Status: LicenseDeletionStatusType
    DeletionDate: str
    ResponseMetadata: ResponseMetadataTypeDef


class ExtendLicenseConsumptionResponseTypeDef(TypedDict):
    LicenseConsumptionToken: str
    Expiration: str
    ResponseMetadata: ResponseMetadataTypeDef


class GetAccessTokenResponseTypeDef(TypedDict):
    AccessToken: str
    ResponseMetadata: ResponseMetadataTypeDef


class RejectGrantResponseTypeDef(TypedDict):
    GrantArn: str
    Status: GrantStatusType
    Version: str
    ResponseMetadata: ResponseMetadataTypeDef


class CheckoutLicenseRequestRequestTypeDef(TypedDict):
    ProductSKU: str
    CheckoutType: CheckoutTypeType
    KeyFingerprint: str
    Entitlements: Sequence[EntitlementDataTypeDef]
    ClientToken: str
    Beneficiary: NotRequired[str]
    NodeId: NotRequired[str]


class CheckoutLicenseResponseTypeDef(TypedDict):
    CheckoutType: CheckoutTypeType
    LicenseConsumptionToken: str
    EntitlementsAllowed: list[EntitlementDataTypeDef]
    SignedToken: str
    NodeId: str
    IssuedAt: str
    Expiration: str
    LicenseArn: str
    ResponseMetadata: ResponseMetadataTypeDef


class CheckoutBorrowLicenseRequestRequestTypeDef(TypedDict):
    LicenseArn: str
    Entitlements: Sequence[EntitlementDataTypeDef]
    DigitalSignatureMethod: Literal["JWT_PS384"]
    ClientToken: str
    NodeId: NotRequired[str]
    CheckoutMetadata: NotRequired[Sequence[MetadataTypeDef]]


class CheckoutBorrowLicenseResponseTypeDef(TypedDict):
    LicenseArn: str
    LicenseConsumptionToken: str
    EntitlementsAllowed: list[EntitlementDataTypeDef]
    NodeId: str
    SignedToken: str
    IssuedAt: str
    Expiration: str
    CheckoutMetadata: list[MetadataTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class LicenseOperationFailureTypeDef(TypedDict):
    ResourceArn: NotRequired[str]
    ResourceType: NotRequired[ResourceTypeType]
    ErrorMessage: NotRequired[str]
    FailureTime: NotRequired[datetime]
    OperationName: NotRequired[str]
    ResourceOwnerId: NotRequired[str]
    OperationRequestedBy: NotRequired[str]
    MetadataList: NotRequired[list[MetadataTypeDef]]


class ConsumptionConfigurationTypeDef(TypedDict):
    RenewType: NotRequired[RenewTypeType]
    ProvisionalConfiguration: NotRequired[ProvisionalConfigurationTypeDef]
    BorrowConfiguration: NotRequired[BorrowConfigurationTypeDef]


class CreateGrantVersionRequestRequestTypeDef(TypedDict):
    ClientToken: str
    GrantArn: str
    GrantName: NotRequired[str]
    AllowedOperations: NotRequired[Sequence[AllowedOperationType]]
    Status: NotRequired[GrantStatusType]
    StatusReason: NotRequired[str]
    SourceVersion: NotRequired[str]
    Options: NotRequired[OptionsTypeDef]


class GrantTypeDef(TypedDict):
    GrantArn: str
    GrantName: str
    ParentArn: str
    LicenseArn: str
    GranteePrincipalArn: str
    HomeRegion: str
    GrantStatus: GrantStatusType
    Version: str
    GrantedOperations: list[AllowedOperationType]
    StatusReason: NotRequired[str]
    Options: NotRequired[OptionsTypeDef]


class ListTagsForResourceResponseTypeDef(TypedDict):
    Tags: list[TagTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class TagResourceRequestRequestTypeDef(TypedDict):
    ResourceArn: str
    Tags: Sequence[TagTypeDef]


class CreateLicenseConversionTaskForResourceRequestRequestTypeDef(TypedDict):
    ResourceArn: str
    SourceLicenseContext: LicenseConversionContextTypeDef
    DestinationLicenseContext: LicenseConversionContextTypeDef


class GetLicenseConversionTaskResponseTypeDef(TypedDict):
    LicenseConversionTaskId: str
    ResourceArn: str
    SourceLicenseContext: LicenseConversionContextTypeDef
    DestinationLicenseContext: LicenseConversionContextTypeDef
    StatusMessage: str
    Status: LicenseConversionTaskStatusType
    StartTime: datetime
    LicenseConversionTime: datetime
    EndTime: datetime
    ResponseMetadata: ResponseMetadataTypeDef


class LicenseConversionTaskTypeDef(TypedDict):
    LicenseConversionTaskId: NotRequired[str]
    ResourceArn: NotRequired[str]
    SourceLicenseContext: NotRequired[LicenseConversionContextTypeDef]
    DestinationLicenseContext: NotRequired[LicenseConversionContextTypeDef]
    Status: NotRequired[LicenseConversionTaskStatusType]
    StatusMessage: NotRequired[str]
    StartTime: NotRequired[datetime]
    LicenseConversionTime: NotRequired[datetime]
    EndTime: NotRequired[datetime]


CreateLicenseManagerReportGeneratorRequestRequestTypeDef = TypedDict(
    "CreateLicenseManagerReportGeneratorRequestRequestTypeDef",
    {
        "ReportGeneratorName": str,
        "Type": Sequence[ReportTypeType],
        "ReportContext": ReportContextTypeDef,
        "ReportFrequency": ReportFrequencyTypeDef,
        "ClientToken": str,
        "Description": NotRequired[str],
        "Tags": NotRequired[Sequence[TagTypeDef]],
    },
)
UpdateLicenseManagerReportGeneratorRequestRequestTypeDef = TypedDict(
    "UpdateLicenseManagerReportGeneratorRequestRequestTypeDef",
    {
        "LicenseManagerReportGeneratorArn": str,
        "ReportGeneratorName": str,
        "Type": Sequence[ReportTypeType],
        "ReportContext": ReportContextTypeDef,
        "ReportFrequency": ReportFrequencyTypeDef,
        "ClientToken": str,
        "Description": NotRequired[str],
    },
)


class LicenseUsageTypeDef(TypedDict):
    EntitlementUsages: NotRequired[list[EntitlementUsageTypeDef]]


class ListDistributedGrantsRequestRequestTypeDef(TypedDict):
    GrantArns: NotRequired[Sequence[str]]
    Filters: NotRequired[Sequence[FilterTypeDef]]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class ListLicenseConfigurationsRequestRequestTypeDef(TypedDict):
    LicenseConfigurationArns: NotRequired[Sequence[str]]
    MaxResults: NotRequired[int]
    NextToken: NotRequired[str]
    Filters: NotRequired[Sequence[FilterTypeDef]]


class ListLicenseConversionTasksRequestRequestTypeDef(TypedDict):
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]
    Filters: NotRequired[Sequence[FilterTypeDef]]


class ListLicenseManagerReportGeneratorsRequestRequestTypeDef(TypedDict):
    Filters: NotRequired[Sequence[FilterTypeDef]]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class ListLicensesRequestRequestTypeDef(TypedDict):
    LicenseArns: NotRequired[Sequence[str]]
    Filters: NotRequired[Sequence[FilterTypeDef]]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class ListReceivedGrantsForOrganizationRequestRequestTypeDef(TypedDict):
    LicenseArn: str
    Filters: NotRequired[Sequence[FilterTypeDef]]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class ListReceivedGrantsRequestRequestTypeDef(TypedDict):
    GrantArns: NotRequired[Sequence[str]]
    Filters: NotRequired[Sequence[FilterTypeDef]]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class ListReceivedLicensesForOrganizationRequestRequestTypeDef(TypedDict):
    Filters: NotRequired[Sequence[FilterTypeDef]]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class ListReceivedLicensesRequestRequestTypeDef(TypedDict):
    LicenseArns: NotRequired[Sequence[str]]
    Filters: NotRequired[Sequence[FilterTypeDef]]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class ListTokensRequestRequestTypeDef(TypedDict):
    TokenIds: NotRequired[Sequence[str]]
    Filters: NotRequired[Sequence[FilterTypeDef]]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class ListUsageForLicenseConfigurationRequestRequestTypeDef(TypedDict):
    LicenseConfigurationArn: str
    MaxResults: NotRequired[int]
    NextToken: NotRequired[str]
    Filters: NotRequired[Sequence[FilterTypeDef]]


class GetServiceSettingsResponseTypeDef(TypedDict):
    S3BucketArn: str
    SnsTopicArn: str
    OrganizationConfiguration: OrganizationConfigurationTypeDef
    EnableCrossAccountsDiscovery: bool
    LicenseManagerResourceShareArn: str
    ResponseMetadata: ResponseMetadataTypeDef


class UpdateServiceSettingsRequestRequestTypeDef(TypedDict):
    S3BucketArn: NotRequired[str]
    SnsTopicArn: NotRequired[str]
    OrganizationConfiguration: NotRequired[OrganizationConfigurationTypeDef]
    EnableCrossAccountsDiscovery: NotRequired[bool]


class ListResourceInventoryRequestRequestTypeDef(TypedDict):
    MaxResults: NotRequired[int]
    NextToken: NotRequired[str]
    Filters: NotRequired[Sequence[InventoryFilterTypeDef]]


class ListAssociationsForLicenseConfigurationResponseTypeDef(TypedDict):
    LicenseConfigurationAssociations: list[LicenseConfigurationAssociationTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListUsageForLicenseConfigurationResponseTypeDef(TypedDict):
    LicenseConfigurationUsageList: list[LicenseConfigurationUsageTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListLicenseSpecificationsForResourceResponseTypeDef(TypedDict):
    LicenseSpecifications: list[LicenseSpecificationTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class UpdateLicenseSpecificationsForResourceRequestRequestTypeDef(TypedDict):
    ResourceArn: str
    AddLicenseSpecifications: NotRequired[Sequence[LicenseSpecificationTypeDef]]
    RemoveLicenseSpecifications: NotRequired[Sequence[LicenseSpecificationTypeDef]]


class ListAssociationsForLicenseConfigurationRequestPaginateTypeDef(TypedDict):
    LicenseConfigurationArn: str
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListLicenseConfigurationsRequestPaginateTypeDef(TypedDict):
    LicenseConfigurationArns: NotRequired[Sequence[str]]
    Filters: NotRequired[Sequence[FilterTypeDef]]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListLicenseSpecificationsForResourceRequestPaginateTypeDef(TypedDict):
    ResourceArn: str
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListResourceInventoryRequestPaginateTypeDef(TypedDict):
    Filters: NotRequired[Sequence[InventoryFilterTypeDef]]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListUsageForLicenseConfigurationRequestPaginateTypeDef(TypedDict):
    LicenseConfigurationArn: str
    Filters: NotRequired[Sequence[FilterTypeDef]]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListResourceInventoryResponseTypeDef(TypedDict):
    ResourceInventoryList: list[ResourceInventoryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListTokensResponseTypeDef(TypedDict):
    Tokens: list[TokenDataTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ProductInformationOutputTypeDef(TypedDict):
    ResourceType: str
    ProductInformationFilterList: list[ProductInformationFilterOutputTypeDef]


ProductInformationFilterUnionTypeDef = Union[
    ProductInformationFilterTypeDef, ProductInformationFilterOutputTypeDef
]


class ReportGeneratorTypeDef(TypedDict):
    ReportGeneratorName: NotRequired[str]
    ReportType: NotRequired[list[ReportTypeType]]
    ReportContext: NotRequired[ReportContextOutputTypeDef]
    ReportFrequency: NotRequired[ReportFrequencyTypeDef]
    LicenseManagerReportGeneratorArn: NotRequired[str]
    LastRunStatus: NotRequired[str]
    LastRunFailureReason: NotRequired[str]
    LastReportGenerationTime: NotRequired[str]
    ReportCreatorAccount: NotRequired[str]
    Description: NotRequired[str]
    S3Location: NotRequired[S3LocationTypeDef]
    CreateTime: NotRequired[str]
    Tags: NotRequired[list[TagTypeDef]]


class ListFailuresForLicenseConfigurationOperationsResponseTypeDef(TypedDict):
    LicenseOperationFailureList: list[LicenseOperationFailureTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class CreateLicenseRequestRequestTypeDef(TypedDict):
    LicenseName: str
    ProductName: str
    ProductSKU: str
    Issuer: IssuerTypeDef
    HomeRegion: str
    Validity: DatetimeRangeTypeDef
    Entitlements: Sequence[EntitlementTypeDef]
    Beneficiary: str
    ConsumptionConfiguration: ConsumptionConfigurationTypeDef
    ClientToken: str
    LicenseMetadata: NotRequired[Sequence[MetadataTypeDef]]


class CreateLicenseVersionRequestRequestTypeDef(TypedDict):
    LicenseArn: str
    LicenseName: str
    ProductName: str
    Issuer: IssuerTypeDef
    HomeRegion: str
    Validity: DatetimeRangeTypeDef
    Entitlements: Sequence[EntitlementTypeDef]
    ConsumptionConfiguration: ConsumptionConfigurationTypeDef
    Status: LicenseStatusType
    ClientToken: str
    LicenseMetadata: NotRequired[Sequence[MetadataTypeDef]]
    SourceVersion: NotRequired[str]


class GrantedLicenseTypeDef(TypedDict):
    LicenseArn: NotRequired[str]
    LicenseName: NotRequired[str]
    ProductName: NotRequired[str]
    ProductSKU: NotRequired[str]
    Issuer: NotRequired[IssuerDetailsTypeDef]
    HomeRegion: NotRequired[str]
    Status: NotRequired[LicenseStatusType]
    Validity: NotRequired[DatetimeRangeTypeDef]
    Beneficiary: NotRequired[str]
    Entitlements: NotRequired[list[EntitlementTypeDef]]
    ConsumptionConfiguration: NotRequired[ConsumptionConfigurationTypeDef]
    LicenseMetadata: NotRequired[list[MetadataTypeDef]]
    CreateTime: NotRequired[str]
    Version: NotRequired[str]
    ReceivedMetadata: NotRequired[ReceivedMetadataTypeDef]


class LicenseTypeDef(TypedDict):
    LicenseArn: NotRequired[str]
    LicenseName: NotRequired[str]
    ProductName: NotRequired[str]
    ProductSKU: NotRequired[str]
    Issuer: NotRequired[IssuerDetailsTypeDef]
    HomeRegion: NotRequired[str]
    Status: NotRequired[LicenseStatusType]
    Validity: NotRequired[DatetimeRangeTypeDef]
    Beneficiary: NotRequired[str]
    Entitlements: NotRequired[list[EntitlementTypeDef]]
    ConsumptionConfiguration: NotRequired[ConsumptionConfigurationTypeDef]
    LicenseMetadata: NotRequired[list[MetadataTypeDef]]
    CreateTime: NotRequired[str]
    Version: NotRequired[str]


class GetGrantResponseTypeDef(TypedDict):
    Grant: GrantTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class ListDistributedGrantsResponseTypeDef(TypedDict):
    Grants: list[GrantTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListReceivedGrantsForOrganizationResponseTypeDef(TypedDict):
    Grants: list[GrantTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListReceivedGrantsResponseTypeDef(TypedDict):
    Grants: list[GrantTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListLicenseConversionTasksResponseTypeDef(TypedDict):
    LicenseConversionTasks: list[LicenseConversionTaskTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class GetLicenseUsageResponseTypeDef(TypedDict):
    LicenseUsage: LicenseUsageTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class GetLicenseConfigurationResponseTypeDef(TypedDict):
    LicenseConfigurationId: str
    LicenseConfigurationArn: str
    Name: str
    Description: str
    LicenseCountingType: LicenseCountingTypeType
    LicenseRules: list[str]
    LicenseCount: int
    LicenseCountHardLimit: bool
    ConsumedLicenses: int
    Status: str
    OwnerAccountId: str
    ConsumedLicenseSummaryList: list[ConsumedLicenseSummaryTypeDef]
    ManagedResourceSummaryList: list[ManagedResourceSummaryTypeDef]
    Tags: list[TagTypeDef]
    ProductInformationList: list[ProductInformationOutputTypeDef]
    AutomatedDiscoveryInformation: AutomatedDiscoveryInformationTypeDef
    DisassociateWhenNotFound: bool
    ResponseMetadata: ResponseMetadataTypeDef


class LicenseConfigurationTypeDef(TypedDict):
    LicenseConfigurationId: NotRequired[str]
    LicenseConfigurationArn: NotRequired[str]
    Name: NotRequired[str]
    Description: NotRequired[str]
    LicenseCountingType: NotRequired[LicenseCountingTypeType]
    LicenseRules: NotRequired[list[str]]
    LicenseCount: NotRequired[int]
    LicenseCountHardLimit: NotRequired[bool]
    DisassociateWhenNotFound: NotRequired[bool]
    ConsumedLicenses: NotRequired[int]
    Status: NotRequired[str]
    OwnerAccountId: NotRequired[str]
    ConsumedLicenseSummaryList: NotRequired[list[ConsumedLicenseSummaryTypeDef]]
    ManagedResourceSummaryList: NotRequired[list[ManagedResourceSummaryTypeDef]]
    ProductInformationList: NotRequired[list[ProductInformationOutputTypeDef]]
    AutomatedDiscoveryInformation: NotRequired[AutomatedDiscoveryInformationTypeDef]


class ProductInformationTypeDef(TypedDict):
    ResourceType: str
    ProductInformationFilterList: Sequence[ProductInformationFilterUnionTypeDef]


class GetLicenseManagerReportGeneratorResponseTypeDef(TypedDict):
    ReportGenerator: ReportGeneratorTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class ListLicenseManagerReportGeneratorsResponseTypeDef(TypedDict):
    ReportGenerators: list[ReportGeneratorTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListReceivedLicensesForOrganizationResponseTypeDef(TypedDict):
    Licenses: list[GrantedLicenseTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListReceivedLicensesResponseTypeDef(TypedDict):
    Licenses: list[GrantedLicenseTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class GetLicenseResponseTypeDef(TypedDict):
    License: LicenseTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class ListLicenseVersionsResponseTypeDef(TypedDict):
    Licenses: list[LicenseTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListLicensesResponseTypeDef(TypedDict):
    Licenses: list[LicenseTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListLicenseConfigurationsResponseTypeDef(TypedDict):
    LicenseConfigurations: list[LicenseConfigurationTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


ProductInformationUnionTypeDef = Union[ProductInformationTypeDef, ProductInformationOutputTypeDef]


class UpdateLicenseConfigurationRequestRequestTypeDef(TypedDict):
    LicenseConfigurationArn: str
    LicenseConfigurationStatus: NotRequired[LicenseConfigurationStatusType]
    LicenseRules: NotRequired[Sequence[str]]
    LicenseCount: NotRequired[int]
    LicenseCountHardLimit: NotRequired[bool]
    Name: NotRequired[str]
    Description: NotRequired[str]
    ProductInformationList: NotRequired[Sequence[ProductInformationTypeDef]]
    DisassociateWhenNotFound: NotRequired[bool]


class CreateLicenseConfigurationRequestRequestTypeDef(TypedDict):
    Name: str
    LicenseCountingType: LicenseCountingTypeType
    Description: NotRequired[str]
    LicenseCount: NotRequired[int]
    LicenseCountHardLimit: NotRequired[bool]
    LicenseRules: NotRequired[Sequence[str]]
    Tags: NotRequired[Sequence[TagTypeDef]]
    DisassociateWhenNotFound: NotRequired[bool]
    ProductInformationList: NotRequired[Sequence[ProductInformationUnionTypeDef]]
